Enum bin_layout::ErrorKind
source · [−]pub enum ErrorKind {
InvalidData,
InsufficientBytes,
Utf8Error(Utf8Error),
FromUtf8Error(FromUtf8Error),
}Expand description
Default Internal errors type
Variants
InvalidData
invalid char or length (for variable-length records).
InsufficientBytes
not enough bytes to read.
Utf8Error(Utf8Error)
Errors which can occur when attempting to interpret a sequence of u8 as a string.
FromUtf8Error(FromUtf8Error)
A possible error value when converting a String from a UTF-8 byte vector.