pub trait Error: Sized {
    fn insufficient_bytes() -> Self;
    fn invalid_data() -> Self;

    fn utf8_err(_: Utf8Error) -> Self { ... }
    fn from_utf8_err(err: FromUtf8Error) -> Self { ... }
}

Required methods

Errors which can occur when not enough bytes are available to read.

Errors which can occur when parsing invalid char, ‘UTF-8’, length (for variable-length records)

Provided methods

Errors which can occur when attempting to interpret a sequence of u8 as a string.

A possible error value when converting a String from a UTF-8 byte vector

Implementations on Foreign Types

Implementors