Trait bin_layout::Error
source · [−]pub trait Error: Sized {
fn insufficient_bytes() -> Self;
fn invalid_data() -> Self;
fn utf8_err(_: Utf8Error) -> Self { ... }
fn from_utf8_err(err: FromUtf8Error) -> Self { ... }
}Required methods
fn insufficient_bytes() -> Self
fn insufficient_bytes() -> Self
Errors which can occur when not enough bytes are available to read.
fn invalid_data() -> Self
fn invalid_data() -> Self
Errors which can occur when parsing invalid char, ‘UTF-8’, length (for variable-length records)
Provided methods
Errors which can occur when attempting to interpret a sequence of u8 as a string.
fn from_utf8_err(err: FromUtf8Error) -> Self
fn from_utf8_err(err: FromUtf8Error) -> Self
A possible error value when converting a String from a UTF-8 byte vector